<?php
if(!defined('PLX_ROOT')) { exit; }

# Calendar widget :
# https://github.com/benhall14/php-calendar (php)
# https://github.com/t1m0n/air-datepicker (javascript)

/* A faire :
 * Si le plugin est supprimé alors supprimer le fichier de données s'il existe
 * */

/**
 * kzEvents addon for PluXml
 *
 * Gestion évènementielle. Ajoute un champ date aux articles dans un fichier indépendant comme tags.xml.
 * Les dates de publication sont stockées dans le tableau $_eVents du plugin
 * Les dates sont sauvegardées au format "2024-09-22T"
 * Incorporer le fichier sample.php au contenu d'une page statique
 *
 * Exemple de code PHP à insérer pour l'affichage d'un article :
 *
 * <?php
 * if(class_exists('kzEvents')) {
 * 		$dateEvent = $plxShow->plxMotor->plxRecord_arts->f(kzEvents::FIELDNAME);
 * 		if(!empty($dateEvent)) {
 * ?>
 * 		<p>
 * 			<span><?= $plxMotor->plxPlugins->aPlugins['kzEvents']->getLang('ARTICLE_EVENT') ?></span>
 * 			<time datetime="<?= $dateEvent ?>">
 * 				<?= plxDate::formatDate(str_replace('-', '', $dateEvent) , '#num_day #month #num_year(4)'); ?>
 * 			</time>
 * 		</p>
 * <?php
 * 		}
 * }
 * ?>
 *
 * Compatible PHP 8.3.11 et PluXml 5.8.16 et PluXml 5.9.0-rc7
 *
 * @author Jean-Pierre Pourrez @bazooka07
 * @version 1.3.2
 * @update 2025-03-13
 * @date 2024-09-19
 * */
class kzEvents extends plxPlugin {
	const FIELDNAME = 'kzEvent';
	const FIELDTYPE = 'datetime-local'; # date vs datetime-local
	const FIELDNAME1 = 'kzEventClosedOn';
	const FIELDTYPE1 = self::FIELDTYPE;
	const FIELDNAME2 = 'kzFile';
	const FIELDTYPE2 = 'text';

	const FIELDNAME3 = 'kzRules';
	const FIELDTYPE3 = 'text';
	const FIELDNAME4 = 'kzLocation';
	const FIELDTYPE4 = 'text';
	const DATAFILE = PLX_ROOT . PLX_CONFIG_PATH . 'plugins/' . __CLASS__.'-data.xml';
	const TIMES = array(
		self::FIELDNAME => '07:00',
		self::FIELDNAME1 => '23:00',
	);
	const XML_HEADER = "<?xml version='1.0' encoding='" . PLX_CHARSET ."'?>" . PHP_EOL;
	const HOOKS = array(
		'plxMotorConstruct',
		'plxMotorParseArticle',
		'plxMotorDemarrageBegin',
	);
	const ADMIN_HOOKS = array(
		'AdminTopEndHead',
		'AdminArticlePreview',
		'AdminArticlePostData',
		'AdminArticleParseData',
		'AdminArticleInitData',
		'AdminArticleFoot',
		'plxAdminEditArticle',
		'plxAdminEditArticleEnd',
		'plxAdminDelArticle',
		'AdminArticleContent',
		'AdminArticleSidebar',
		'AdminMediasFoot',
		'AdminIndexFoot',
	);
	const ISO_DATE_PATTERN = '#^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2})(?::\d{2})?$#';
	const SEARCH_AND_REPLACE_DATE = array('-', 'T', ':',);

	const BEGIN_CODE = '<?php # ' . __CLASS__ . ' plugin' . PHP_EOL;
	const END_CODE = PHP_EOL . '?>';

	private $_aEvents;

	public function __construct($lang) {
		parent::__construct($lang);

		parent::setConfigProfil(PROFIL_ADMIN, PROFIL_MANAGER);

		foreach(self::HOOKS as $hook) {
			parent::addHook($hook, $hook);
		}

		if(defined('PLX_ADMIN')) {
			foreach(self::ADMIN_HOOKS as $hook) {
				parent::addHook($hook, $hook);
			}
		} else {
			# Hook à appeler depuis le site
			$hook = 'kzEvent';
			parent::addHook($hook, $hook);
			if(!empty($this->getParam('cat'))) {
				$hook = 'plxMotorPreChauffageEnd';
				parent::addHook($hook, $hook);

			}
		}

		# Mimics plxPlugins::getPluginLang()
		/*
		$this->default_lang = $lang;
		$this->aLang = self::LANG[$lang];
		* */
	}

	/*
	 * Actualise la date de publication de l'évènement
	 * */
	public function updateDate($artId, $datePublication='') {
		$this->_aEvents[$artId]['date'] = $datePublication;
	}

	/*
	 * Enregistrement de la valeur du nouveau champ pour l'article en cours d'édition
	 * */
	public function editEvent($artId, $data) {
		if(is_array($data) and !empty($data[self::FIELDNAME])) {

			if(array_key_exists($artId, $this->_aEvents) and empty(array_diff_assoc($data, $this->_aEvents[$artId]))) {
				# Aucun changement
				return;
			}

			# Mise à jour
			$this->_aEvents[$artId] = $data;
		} elseif(!array_key_exists($artId, $this->_aEvents)) {
			# Aucun changement
			return;
		} else {
			unset($this->_aEvents[$artId]);
		}
		# sauvegarde
		$this->editEvents();
	}

	/*
	 * Enregistrement des champs des évènements pour chaque article dans un fichier séparé.
	 * */
	public function editEvents() {
		# Génération du fichier XML
		if(empty($this->_aEvents)) {
			if(file_exists(self::DATAFILE)) {
				unlink(self::DATAFILE);
			}
			return;
		}

		# on trie $datas selon la valeur pour la clé self::FIELDNAME
		uasort($this->_aEvents, function($a, $b) {
			$result = strcmp($a[self::FIELDNAME], $b[self::FIELDNAME]);
			if($result != 0) {
				# tri sur dates d'évènements
				return $result;
			}

			# tri sur dates de publication
			return strcmp($a['date'], $b['date']);
		});
		ob_start();
?>
<document>
<?php
		foreach($this->_aEvents as $art_id => $value) {
			$dates = $value[self::FIELDNAME];
			if(!empty($value[self::FIELDNAME1])) {
				$dates .= ',' . $value[self::FIELDNAME1];
			}
?>
	<article number="<?= $art_id ?>" date="<?= $value['date'] ?>" active="<?= $value['active'] ?>" <?= self::FIELDNAME2 ?>="<?= $value[self::FIELDNAME2] ?>" <?= self::FIELDNAME3 ?>="<?= $value[self::FIELDNAME3] ?>" <?= self::FIELDNAME4 ?>="<?= $value[self::FIELDNAME4] ?>"><?= $dates ?></article>
<?php
		}
?>
</document>
<?php
		# On écrit le fichier
		plxUtils::write(self::XML_HEADER . ob_get_clean(), self::DATAFILE);
	}

	/*
	 * Suppression de la valeur du nouveau champ en cas de suppression de l'article.
	 * */
	public function delEvent($artId) {
		if(array_key_exists($artId, $this->_aEvents)) {
			unset($this->_aEvents[$artId]);
			$this->editEvents();
		}
	}

	/**
	 * Remplace la date de publication par celle d'évènement dans le tableau articles.
	 * */
	public function AdminIndexFootAppend() {
		if(empty($this->_aEvents)) {
			return;
		}

		$title = addslashes($this->getLang('PUBLISH_ON'));
?>
<script> <!-- <?= __CLASS__ ?> plugin -->
	(function() {
		'use strict';
 		const dateEvents = {
<?php
		foreach($this->_aEvents as $artId=>$values) {
			$dateEvent = plxDate::formatDate(str_replace(self::SEARCH_AND_REPLACE_DATE, '', $values[self::FIELDNAME]));
?>
			'<?= $artId ?>' : '<?= $dateEvent ?>',
<?php
		}
?>
		};

		const artsTable = document.querySelector('#articles-table tbody');

		if(artsTable) {
			Array.from(artsTable.rows).forEach(function(row) {
				const artId = row.cells[0].querySelector('input').value;
				if(artId in dateEvents) {
					const cell2 = row.cells[2];
					const tag = document.createElement('span');
					tag.textContent = dateEvents[artId];
					tag.title = '<?= $title ?>' + cell2.textContent;
					tag.classList.add('<?= self::FIELDNAME ?>');
					cell2.textContent = '';
					cell2.append(tag);
				}
			});
		}
	})();
</script>
<?php	}

	public function onDelete() {
		if(file_exists(self::DATAFILE)) {
			unlink(self::DATAFILE);
		}
	}

	/*
	 * Récupère la date d'évènement selon l'identifiant de l'article si elle existe.
	 * */
	 public function getEvent($artId, $field=self::FIELDNAME) {
		return (
			is_array($this->_aEvents) and
			array_key_exists($artId, $this->_aEvents) and
			array_key_exists($field, $this->_aEvents[$artId])
		) ? $this->_aEvents[$artId][$field] : '';
	}

	public function getArticles() {
	}

	/* === Hooks === */

	/*
	 * Récupération des évènements au démarrage de PluXml.
	 * */
	public function plxMotorConstruct() {
		# Mimics plxMotor::getTags()
		$array = array();
		if(file_exists(self::DATAFILE)) {
			$data = implode('',file(self::DATAFILE));
			$parser = xml_parser_create(PLX_CHARSET);
			xml_parser_set_option($parser,XML_OPTION_CASE_FOLDING,0);
			xml_parser_set_option($parser,XML_OPTION_SKIP_WHITE,0);
			xml_parse_into_struct($parser,$data,$values,$iTags);
			xml_parser_free($parser);
			# On vérifie s'il existe des tags 'article'
			if(isset($iTags['article'])) {
				# $plxMotor = plxMotor::getInstance();
				foreach($iTags['article'] as $idx) {
					$item = $values[$idx];
					$attrs = $item['attributes'];
					$artId = $attrs['number'];
					if(isset($item['value'])) {
						$dates = explode(',', trim($item['value']));
						if(count($dates) < 2) {
							$dates[] = '';
						}
					} else {
						$dates = array('', '');
					}
					$array[$artId] = array(
						self::FIELDNAME  => $dates[0],
						self::FIELDNAME1 => $dates[1],
						self::FIELDNAME2 => isset($attrs[self::FIELDNAME2]) ? $attrs[self::FIELDNAME2] : '',
						self::FIELDNAME3 => isset($attrs[self::FIELDNAME3]) ? $attrs[self::FIELDNAME3] : '',
						self::FIELDNAME4 => isset($attrs[self::FIELDNAME4]) ? $attrs[self::FIELDNAME4] : '',
						'date'   => $attrs['date'],
						'active' => $attrs['active'],
					);
				}
			}

			# On contrôle l'intégrité des dates
			$dt = (self::FIELDTYPE == 'date'); # vs datetime-local
			$pattern = '#^(\d{4}-\d{2}-\d{2})(T\d{2}:\d{2})?$#';
			foreach($array as $artId=>$values) {
				foreach(array(self::FIELDNAME, self::FIELDNAME1) as $k) {
					if(!empty($values[$k])) {
						if(preg_match($pattern, $values[$k], $matches)) {
							if($dt) {
								$array[$artId][$k] = $matches[1];
							} elseif(empty($matches[2])) {
								$array[$artId][$k] = $matches[1] . 'T' . self::TIMES[$k];
							}
						} else {
							$array[$artId][$k] = '';
						}
					}
				}
			}
		}

		$this->_aEvents = $array;
		if(!empty($array)) {
			$artIds = array_keys($array);

			echo self::BEGIN_CODE;
			# On met à jour la date de publication de l'article
?>
$glob_arts = $this->plxGlob_arts;
if($glob_arts) {
	$root = PLX_ROOT . $this->aConf['racine_articles'];
	$kzPlugin = $this->plxPlugins->aPlugins['<?= __CLASS__ ?>'];
	foreach(array('<?= implode("', '", array_keys($array)) ?>') as $artId) {
		$filename = $root . $glob_arts->aFiles[$artId];
		$artInfos = $this->artInfoFromFilename($filename);
		if($artInfos) {
			$kzPlugin->updateDate($artId, $artInfos['artDate']);
		}
	}
}
	<?php
			echo self::END_CODE;
		}
	}

	/*
	 * On récupère la date d'évènement pour l'édition d'un article via la méthode self::getEvent().
	 * */
	public function plxMotorParseArticle() {
		echo self::BEGIN_CODE;
?>
$kzPlugin = $this->plxPlugins->aPlugins['<?= __CLASS__ ?>'];
$art['<?= self::FIELDNAME ?>'] = $kzPlugin->getEvent($tmp['artId']);
$art['<?= self::FIELDNAME1 ?>'] = $kzPlugin->getEvent($tmp['artId'], '<?= self::FIELDNAME1 ?>');
$art['<?= self::FIELDNAME2 ?>'] = $kzPlugin->getEvent($tmp['artId'], '<?= self::FIELDNAME2 ?>');
$art['<?= self::FIELDNAME3 ?>'] = $kzPlugin->getEvent($tmp['artId'], '<?= self::FIELDNAME3 ?>');
$art['<?= self::FIELDNAME4 ?>'] = $kzPlugin->getEvent($tmp['artId'], '<?= self::FIELDNAME4 ?>');
<?php
		echo self::END_CODE;
	}

	/*
	 * Remplace plxMotor::getArticles() par self:getArticles() pour la catégorie choisie
	 * */
	public function plxMotorDemarrageBegin() {
		$catId = $this->getParam('cat');
		if(empty($catId)) {
			return;
		}

		echo self::BEGIN_CODE;
?>
if($this->mode == 'categorie' and $this->cible == '<?= $catId ?>') {
	$this->getPage();
	# on modifie le motif avec les codes articles et on fait sans tri
	$kzOldTri = $this->tri;
	$this->tri = '';
	if(!$this->getArticles()) {
		# Si aucun article
		$this->error404(L_NO_ARTICLE_PAGE);
	}
	# On retrie les articles dans l'ordre demandé

	# On restaure le tri initial
	$this->tri = $kzOldTri;
}
<?php
		echo self::END_CODE;
	}

	/* === Hooks for back-office === */

	public function AdminTopEndHead() {
?>
		<style>
			.sidebar input[name="<?= self::FIELDNAME2 ?>"] {
				width: calc(100% - 4.5em);
			}
		</style>
<?php
	}

	public function AdminArticlePreview() {
		echo self::BEGIN_CODE;
?>
$art['<?= self::FIELDNAME ?>'] = $_POST['<?= self::FIELDNAME ?>'];
$art['<?= self::FIELDNAME1 ?>'] = $_POST['<?= self::FIELDNAME1 ?>'];
$art['<?= self::FIELDNAME2 ?>'] = $_POST['<?= self::FIELDNAME2 ?>'];
$art['<?= self::FIELDNAME3 ?>'] = $_POST['<?= self::FIELDNAME3 ?>'];
$art['<?= self::FIELDNAME4 ?>'] = $_POST['<?= self::FIELDNAME4 ?>'];
<?php
		echo self::END_CODE;
	}

	public function AdminArticlePostData() {
		echo self::BEGIN_CODE;
?>
$kzEvent = $_POST['<?= self::FIELDNAME ?>'];
$kzEvent1 = $_POST['<?= self::FIELDNAME1 ?>'];
$kzEvent2 = $_POST['<?= self::FIELDNAME2 ?>'];
$kzEvent3 = $_POST['<?= self::FIELDNAME3 ?>'];
$kzEvent4 = $_POST['<?= self::FIELDNAME4 ?>'];
<?php
		echo self::END_CODE;
	}

	public function AdminArticleParseData() {
		echo self::BEGIN_CODE;
?>
$kzEvent = $result['<?= self::FIELDNAME ?>'];
$kzEvent1 = $result['<?= self::FIELDNAME1 ?>'];
$kzEvent2 = $result['<?= self::FIELDNAME2 ?>'];
$kzEvent3 = $result['<?= self::FIELDNAME3 ?>'];
$kzEvent4 = $result['<?= self::FIELDNAME4 ?>'];
<?php
		echo self::END_CODE;
	}

	/*
	 * Inialise la date d'évènement pour un nouvel article.
	 * */
	public function AdminArticleInitData() {
		echo self::BEGIN_CODE;
?>
$kzEvent = '';
$kzEvent1 = '';
$kzEvent2 = '';
$kzEvent3 = '';
$kzEvent4 = '';
<?php
		echo self::END_CODE;
	}

	public function AdminArticleFoot() {
?>
	<script>
		(function(id) {
			const el = document.getElementById(id);
			if(el) {
				const target = document.getElementById(id + '_file');

				if(target) {
					function previewDoc() {
						const value = el.value.trim();
						const disabled = (el.value.length == 0);
						console.log('Disabled : ' + disabled);
						if(disabled) {
							target.removeAttribute('href');
							target.classList.add('disabled');
						} else {
							target.href = '<?= PLX_ROOT ?>' + value;
							target.classList.remove('disabled');
						}
					}

					el.addEventListener('change', function(ev) {
						previewDoc();
					});

					previewDoc();
				}
			} else {
				console.error('#' + id + ' element not found');
			}
		})('id_<?= self::FIELDNAME2 ?>');
	</script>
<?php
	}

	/*
	 * Gestion de la catégorie dédiée aux évènements pour cet article
	 * */
	public function plxAdminEditArticle() {
		$catId = $this->getParam('cat');
		echo self::BEGIN_CODE;
?>
$kzEventDate = trim($content['<?= self::FIELDNAME ?>']);
$kzCatId = '<?= $catId ?>';
if(!empty($kzCatId)) {
	# gestion automatique de la catégorie pour les évènements
	if(!empty($kzEventDate)) {
		if(!in_array($kzCatId, $content['catId'])) {
			$content['catId'][] = $kzCatId;
		}
	} else {
		$k = array_search($kzCatId, $content['catId']);
		if(is_integer($k)) {
			unset($content['catId'][$k]);
		}
	}
}
<?php
		echo self::END_CODE;
	}

	/*
	 * Sauvegarde la date d'évènement via la méthode self::editEvent()
	 * */
	public function plxAdminEditArticleEnd() {
		echo self::BEGIN_CODE;
		# $kzEventDate est instancié par self::plxAdminEditArticle()
?>
$this->plxPlugins->aPlugins['<?= __CLASS__ ?>']->editEvent($id, array(
	'<?= self::FIELDNAME ?>' => $kzEventDate,
	'<?= self::FIELDNAME1 ?>' => trim($content['<?= self::FIELDNAME1 ?>']),
	'<?= self::FIELDNAME2 ?>' => trim($content['<?= self::FIELDNAME2 ?>']),
	'<?= self::FIELDNAME3 ?>' => trim($content['<?= self::FIELDNAME3 ?>']),
	'<?= self::FIELDNAME4 ?>' => trim($content['<?= self::FIELDNAME4 ?>']),
	'date' => isset($dates['publication']) ? $dates['publication'] : $time, # For PluXMl > 5.9.0
	'active' => intval(!in_array('draft', $content['catId'])),
));

<?php
		echo self::END_CODE;
	}

	/*
	 * Supprime éventuellement le champ évènement si l'article est supprimé.
	 * */
	public function plxAdminDelArticle() {
		echo self::BEGIN_CODE;
?>
if($resDelArt AND $resDelCom) {
	$this->plxPlugins->aPlugins['<?= __CLASS__ ?>']->delEvent($id);
}

# Process must continue for tags
return false;
<?php
		echo self::END_CODE;
	}

	/*
	 * On bufférise la sortie HTML pour positionner le nouveau champ de saisie.
	 * */
	public function AdminArticleContent() {
		ob_start();
		ob_start(); # Against plxPlugins::callHook()
	}

	/*
	 * Ajoute dans la sidebar de l'édition d'un article un champ pour saisir un champ type date.
	 * Le champ est positionné après les dates origniales de PluXml via preg_replace().
	 * */
	public function AdminArticleSidebar() {
		ob_get_clean(); # Against plxPlugins::callHook()
		$content = ob_get_clean();

		$caption = $this->getLang('ARTICLE_EVENT');
		$caption1 = $this->getLang('ARTICLE_EVENT_CLOSED_ON');
		$caption2 = $this->getLang('FILE_EVENT');
		$caption3 = $this->getLang('RULES_EVENT');
		$caption4 = $this->getLang('LOCATION_EVENT');
		ob_start();
?>
						<label for="id_<?= self::FIELDNAME ?>"><?= $caption ?>&nbsp;:</label>
<?php
		echo '<?php ';
?>
plxUtils::printInput('<?= self::FIELDNAME ?>', $kzEvent, '<?= self::FIELDTYPE ?>', '');
<?php
		echo ' ?>' . PHP_EOL;
?>
					</div>
				</div>
				<div class="grid">
					<div class="col sml-12">
						<label for="id_<?= self::FIELDNAME1 ?>"><?= $caption1 ?>&nbsp;:</label>
<?php
		echo '<?php ';
?>
plxUtils::printInput('<?= self::FIELDNAME1 ?>', $kzEvent1, '<?= self::FIELDTYPE1 ?>', '');
<?php
		echo ' ?>' . PHP_EOL;
?>
					</div>
				</div>
				<div class="grid">
					<div class="col sml-12">
						<label for="id_<?= self::FIELDNAME3 ?>"><?= $caption3 ?>&nbsp;:</label>
<?php
		echo '<?php ';
?>
plxUtils::printInput('<?= self::FIELDNAME3 ?>', $kzEvent3, '<?= self::FIELDTYPE3 ?>', '');
<?php
		echo ' ?>' . PHP_EOL;
?>
					</div>
				</div>
				<div class="grid">
					<div class="col sml-12">
						<label for="id_<?= self::FIELDNAME4 ?>"><?= $caption4 ?>&nbsp;:</label>
<?php
		echo '<?php ';
?>
plxUtils::printInput('<?= self::FIELDNAME4 ?>', $kzEvent4, '<?= self::FIELDTYPE4 ?>', '');
<?php
		echo ' ?>' . PHP_EOL;
?>					</div>
				</div>
				<div class="grid">
					<div class="col sml-12">
						<label for="id_<?= self::FIELDNAME2 ?>"><?= $caption2 ?>&nbsp;:</label>
<?php
		echo '<?php ';
?>
plxUtils::printInput('<?= self::FIELDNAME2 ?>', $kzEvent2, '<?= self::FIELDTYPE2 ?>', '');
<?php
		echo ' ?>' . PHP_EOL;
?>
						<a title="<?= L_THUMBNAIL_SELECTION ?>" id="toggler_<?= self::FIELDTYPE2 ?>" href="javascript:void(0)" onclick = "mediasManager.openPopup('id_<?= self::FIELDNAME2 ?>', true, 'updateDocViewer');" class="button" style="outline:none; text-decoration: none">+</a>
						<a id="id_<?= self::FIELDNAME2 ?>_file" class="button" title="<?= L_DISPLAY ?>" target="_blank">&#128442;</a>
					</div>
				</div>
				<div class="grid">
					<div class="col sml-12">
<?php
		$replace = ob_get_clean();
		echo preg_replace('#(<label>' . L_ARTICLE_CATEGORIES . '\&nbsp;:</label>)#', $replace . "$1", $content);
	}

	/*
	 * Met à jour le lien pour ouvrir le document
	 * */
	public function AdminMediasFoot() {
?>
<script>
		function updateDocViewer(cibleId, href, replace) {
			// function appelée depuis la fenêtre popup de medias.php
			'use strict';
			mediasManager.addText(cibleId, href, replace);
			const cible = window.opener.document.getElementById(cibleId + '_file');
			if (cible) {
				// window.opener.console.log(href);
				const disabled = (href.trim().length == 0);
				if(disabled) {
					cible.removeAttr('href')
					cible.classList.add('disabled');
				} else {
					cible.href = href.trim();
					cible.classList.remove('disabled');
				}
				cible.disabled = disabled;
			} else {
				window.opener.console.error('#' + cibleId + '_file element not found');
			}
		}
</script>
<?php
	}

	/*
	 * Affiche la date des évènements dans le tableau des articles via la méthode self::AdminIndexFootAppend())
	 * */
	public function AdminIndexFoot() {
		echo self::BEGIN_CODE;
?>
if(!empty($arts)) {
	$plxAdmin->plxPlugins->aPlugins['<?= __CLASS__ ?>']->AdminIndexFootAppend();
}
<?php
		echo self::END_CODE;
	}

	/* === Hooks for thema === */

	/*
	 * On utilise le template fourni par le plugin pour la catégorie choisie
	 *
	 * Ne fonctionne pas si le dossier du thème est un lien symbolique (Voir Linux).
	 * Dns ce cas créer un lien symbolique dans le dossier réel du thème vers letemplate du plugin.
	 * */
	public function plxMotorPreChauffageEnd() {
		echo self::BEGIN_CODE;
?>
if(
	$this->mode != 'categorie' or
	$this->cible != '<?= $this->getParam('cat') ?>' or
	<?= intval($this->getParam('use_template')) ?> != 1
) {
	return;
}
$kzTemplate = 'categorie-<?= __CLASS__ ?>.php';
$filename = PLX_ROOT . $this->aConf['racine_themes'] . $this->style . '/' . $kzTemplate;
if($this->template != $kzTemplate and file_exists($filename)) {
	$this->template = $kzTemplate;
} elseif(!is_link(PLX_ROOT . $this->aConf['racine_themes'] . $this->style)) {
	$this->template = '../.' . PLX_PLUGINS . '<?= __CLASS__ ?>/' . $kzTemplate;
}
<?php
		echo self::END_CODE;
	}

	/*
	 * @parameter params type string : 'before', 'after', 'all'
	 * */
	public function kzEvent($params) {
		# Emulation de plxMotor::getArticles('all')
		$motif = false;
		if(!empty($this->_aEvents)) {
			if(!is_string($params)) {
				$params = 'after';
			}
			$today = date('Y-m-d');
			$events = array_filter($this->_aEvents, function($value) use($params, $today) {
				if(empty($value['active'])) {
					return false;
				}
				switch($params) {
					case 'after': return (strcmp($today, $value[self::FIELDNAME]) <= 0); break;
					case 'before': return (strcmp($today, $value[self::FIELDNAME]) > 0); break;
					default: return true;
				}
			});

			if(!empty($events)) {
				$motif = (count($events) > 1) ?'#^(' . implode('|', array_keys($events)) . ')\.#' : '#^' . array_keys($events)[0] . '\.#';
			}
		}

		$plxMotor = plxMotor::getInstance();
		if(!empty($motif) and ($aFiles = $plxMotor->plxGlob_arts->query($motif, 'art'))) {
			# On analyse tous les fichiers
			$artsList = array();
			foreach($aFiles as $v) {
				$art = $plxMotor->parseArticle(PLX_ROOT . $plxMotor->aConf['racine_articles'] . $v);
				if(!empty($art)) {
					$artsList[] = $art;
				}
			}

			# On trie selon les dates d'évènements
			switch($params) {
				case 'after':
				case '':
					# tri croissant
					usort($artsList, function($a, $b) {
						$test = strcmp($a[self::FIELDNAME], $b[self::FIELDNAME]);
						if($test === 0) {
							# 2 évènements le même jour
							return strcmp($a['numero'], $b['numero']);
						}
					    return $test;
					});
					break;
				case 'before':
					# tri décroissant
					usort($artsList, function($a, $b) {
						$test = strcmp($b[self::FIELDNAME], $a[self::FIELDNAME]);
						if($test === 0) {
							# 2 évènements le même jour
							return strcmp($a['numero'], $b['numero']);
						}
					    return $test;
					});
					break;
				default:
					# tri croissant pour le futur et décroissanr pour le passé
					usort($artsList, function($a, $b) use($today) {
						$test = strcmp($a[self::FIELDNAME], $b[self::FIELDNAME]);
						if($test === 0) {
							# 2 évènements le même jour
							return strcmp($a['numero'], $b['numero']);
						}

						$testB = (strcmp($b[self::FIELDNAME], $today) >= 0);
						if(strcmp($a[self::FIELDNAME], $today) >= 0) {
							# évènement du jour ou prochain
							return $testB ? $test : -1;
						} else {
							# évènement passé
							return $testB ? 1 : -$test;
						}
					});
			}

			# On stocke les enregistrements dans un objet plxRecord
			$plxMotor->plxRecord_arts = new plxRecord($artsList);
?>
<!--
<p><?= count($artsList) ?> events</p>
-->
<?php
			return true;
		} else {
			# Aucun évènement à afficher
?>
<p><?php $this->lang('NO_EVENT'); ?></p>
<?php
			return false;
		}
	}

}
